@@ -1,4 +1,4 @@
 from askdata.askdata_client import *
 from NotebookScripter import receive_parameter
-from askdata.human2sql import ask_dataframe
+from askdata.human2query import ask_dataframe
 from askdata import askdata_pandas_extension
\ No newline at end of file
