@@ -153,12 +153,9 @@ class Dataset():
 
         if dataset_id != '':
             pass
-        elif hasattr(self, '_dataset_slug') is not None and dataset_id == '':
+        elif dataset_id == '':
             dataset_id = self._dataset_id
             logging.info("---- sync dataset with id '{}' ----- ".format(str(self._dataset_id)))
-        else:
-            raise Exception("takes 2 positional arguments but dataset_id weren't given or dataset didn't"
-                            " instantiate with slug")
 
         dataset_url = self._base_url_askdata + '/smartdataset/datasets/' + dataset_id + '/sync'
         r = requests.post(url=dataset_url, headers=self._headers)
