@@ -176,7 +176,7 @@ def query2sql(smartquery, driver):
         logging.error(str(e))
 
 
-def nl2query(nl, language):
+def nl2query(nl, language="en-US"):
     # Google Pod
     headers = {
         "Content-Type": "application/json"
@@ -189,10 +189,10 @@ def nl2query(nl, language):
 
     url = url_list['BASE_URL_NL2QUERY_DEV'] + "/query"
 
-    if "en" in language:
-        language = "en-US"
-    elif "it" in language:
+    if "it" in language:
         language = "it-IT"
+    else:
+        language = "en-US"
 
     data = {
         "nl_ner": nl,
