@@ -135,8 +135,6 @@ class Insight_Definition:
                 for col in cols:
                     columns.append(col)
 
-        print(columns)
-
         settings = {}
         for field in field_codes.keys():
             for column in columns:
@@ -155,8 +153,6 @@ class Insight_Definition:
         for key in values.keys():
             settings[key + "_id"] = values[key]
 
-        print(settings)
-
         body = {
             "id" : widget_id,
             "type": "widget",
