@@ -8,6 +8,9 @@ from googleapiclient.discovery import build
 from requests.adapters import HTTPAdapter
 from urllib3 import Retry
 
+import json
+
+
 """ 
 Read google sheet as dataframe
 
@@ -16,7 +19,9 @@ If you read with API, you need to use spreadsheetId and credentials (it is the j
 you also need to add the account email associated to the credentials as user shared in the google sheet.
 
 """
-def read_gsheet(spreadsheetId, credentials = None, sheet = None, valueRenderOption = 'FORMATTED_VALUE'):
+def read_gsheet(spreadsheetId, credentials = None, sheet = None, 
+
+                valueRenderOption = 'FORMATTED_VALUE', dateTimeRenderOption = 'SERIAL_NUMBER'):
     
 
     if credentials is None:
@@ -25,7 +30,9 @@ def read_gsheet(spreadsheetId, credentials = None, sheet = None, valueRenderOpti
         
         body = {
             "spreadsheetId": spreadsheetId,
-            "sheet": sheet
+            "sheet": sheet,
+            "valueRenderOption": valueRenderOption,
+            "dateTimeRenderOption": dateTimeRenderOption
         }
         
         s = requests.Session()
@@ -37,7 +44,8 @@ def read_gsheet(spreadsheetId, credentials = None, sheet = None, valueRenderOpti
         }
         r = s.post(url=post_url, json=body, headers=headers)
         r.raise_for_status()
-        df = pd.read_json(r.json())
+        
+        df = pd.DataFrame(json.loads(r.json()))
 
     else: 
 
@@ -57,7 +65,8 @@ def read_gsheet(spreadsheetId, credentials = None, sheet = None, valueRenderOpti
         
         result_input = sheet_service.values().get(spreadsheetId = spreadsheetId,
                                           range = range,
-                                          ValueRenderOption = ValueRenderOption).execute()
+                                          valueRenderOption = valueRenderOption,
+                                          dateTimeRenderOption = dateTimeRenderOption).execute()
         
         values_input = result_input.get('values', [])
         
@@ -168,7 +177,10 @@ def __read_excel(settings: dict):
     return df
 
 def __read_gsheet(settings: dict):
-    df = read_gsheet(spreadsheetId=settings["spreadsheetId"], credentials=settings["credentials"], sheet=settings["sheet"])
+    df = read_gsheet(spreadsheetId=settings["spreadsheetId"], credentials=settings["credentials"], sheet=settings["sheet"],
+    
+                    valueRenderOption = settings['valueRenderOption'],  dateTimeRenderOption = settings['dateTimeRenderOption'])
+                    
     return df
 
 def __read_hubspot(settings: dict):
