@@ -407,74 +407,81 @@ class Query:
 
         for where_condition in where:
             if isinstance(where_condition, Condition):
-                vars = []
-                if where_condition.value is not None:
-                    for var in where_condition.value:
-                        vars.append(str(var))
-                    formatted_value = "( " + ", ".join(vars) + " )"
-                else:
-                    formatted_value = None
-
-                if isinstance(where_condition.operator, str):
-                    if where_condition.negate is None:
-                        operator = where_condition.operator
+                if where_condition.field.column is not None:
+                    vars = []
+                    if where_condition.value is not None:
+                        for var in where_condition.value:
+                            vars.append(str(var))
+                        formatted_value = "( " + ", ".join(vars) + " )"
                     else:
-                        operator = "NOT " + where_condition.operator
-                elif isinstance(where_condition.operator, SQLOperator) or isinstance(where_condition.operator,
-                                                                                     TimeOperator):
-                    operator = where_condition.operator.name
-                    if operator == "IN":
-                        if where_condition.negate is None:
-                            operator = where_condition.operator.name
-                        else:
-                            operator = "NOT " + where_condition.operator.name
-                    elif operator == "GOE":
-                        if where_condition.negate is None:
-                            operator = ">="
-                        else:
-                            operator = "<"
-                    elif operator == "LOE":
-                        if where_condition.negate is None:
-                            operator = "<="
-                        else:
-                            operator = ">"
-                    elif operator == "EQ":
-                        if where_condition.negate is None:
-                            operator = "=="
-                        else:
-                            operator = "!="
-                    elif operator == "GT":
-                        if where_condition.negate is None:
-                            operator = ">"
-                        else:
-                            operator = "<="
-                    elif operator == "LT":
-                        if where_condition.negate is None:
-                            operator = "<"
-                        else:
-                            operator = ">="
-                else:
-                    operator = None
+                        formatted_value = None
 
-                consistent_vec = consistent_datatypes[where_condition.field.internalDataType.lower()]
-                if (
-                        where_condition.field.internalDataType.lower() == "numeric" or where_condition.field.internalDataType.lower() == "string") \
-                        and where_condition.field.sourceDataType.lower() not in consistent_vec:
-                    # if internal and original data types are not consistent each other use this pattern
-                    # aggregation column (original data type, to internal data type ) AS Alias
-                    formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
-                elif where_condition.field.internalDataType.lower() == "date" and where_condition.field.sourceDataType.lower() not in consistent_vec:
-                    # if internal and original data types are not consistent each other use this pattern
-                    # aggregation column (original data type, to internal data type, date_format YYYY-MM-DD ) AS Alias
-                    if where_condition.field.sourceFormat is not None:
-                        formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format " + where_condition.field.sourceFormat + ") " + operator + " " + formatted_value
+                    if isinstance(where_condition.operator, str):
+                        if where_condition.negate is None:
+                            operator = where_condition.operator
+                        else:
+                            operator = "NOT " + where_condition.operator
+                    elif isinstance(where_condition.operator, SQLOperator) or isinstance(where_condition.operator,
+                                                                                         TimeOperator):
+                        operator = where_condition.operator.name
+                        if operator == "IN":
+                            if where_condition.negate is None:
+                                operator = where_condition.operator.name
+                            else:
+                                operator = "NOT " + where_condition.operator.name
+                        elif operator == "GOE":
+                            if where_condition.negate is None:
+                                operator = ">="
+                            else:
+                                operator = "<"
+                        elif operator == "LOE":
+                            if where_condition.negate is None:
+                                operator = "<="
+                            else:
+                                operator = ">"
+                        elif operator == "EQ":
+                            if where_condition.negate is None:
+                                operator = "=="
+                            else:
+                                operator = "!="
+                        elif operator == "GT":
+                            if where_condition.negate is None:
+                                operator = ">"
+                            else:
+                                operator = "<="
+                        elif operator == "LT":
+                            if where_condition.negate is None:
+                                operator = "<"
+                            else:
+                                operator = ">="
                     else:
-                        formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format YYYY-MM-DD" + ") " + operator + " " + formatted_value
-                else:
-                    # else
-                    formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ") " + operator + " " + formatted_value
+                        operator = None
 
-                conditions.append(formatted_cond)
+                    consistent_vec = consistent_datatypes[where_condition.field.internalDataType.lower()]
+                    if (
+                            where_condition.field.internalDataType.lower() == "numeric" or where_condition.field.internalDataType.lower() == "string") \
+                            and where_condition.field.sourceDataType.lower() not in consistent_vec:
+                        # if internal and original data types are not consistent each other use this pattern
+                        # aggregation column (original data type, to internal data type ) AS Alias
+                        formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
+                    elif where_condition.field.internalDataType.lower() == "date" and where_condition.field.sourceDataType.lower() not in consistent_vec:
+                        # if internal and original data types are not consistent each other use this pattern
+                        # aggregation column (original data type, to internal data type, date_format YYYY-MM-DD ) AS Alias
+                        if where_condition.field.sourceFormat is not None:
+                            formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format " + where_condition.field.sourceFormat + ") " + operator + " " + formatted_value
+                        else:
+                            formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format YYYY-MM-DD" + ") " + operator + " " + formatted_value
+                    else:
+                        # else
+                        formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ") " + operator + " " + formatted_value
+
+                    conditions.append(formatted_cond)
+                elif where_condition.field.complexExpression is not None:
+                    if where_condition.field.alias is not None:
+                        formatted_cond = where_condition.field.complexExpression + " AS " + where_condition.field.alias
+                    else:
+                        formatted_cond = where_condition.field.complexExpression
+                    conditions.append(formatted_cond)
             elif isinstance(where_condition, CompositeCondition):
                 other_conds = self._where_spell_out(where_condition.conditions)
                 if where_condition.operator.name == "AND":
