@@ -40,39 +40,9 @@ if __name__ == "__main__":
         ]
     )
 
-    response = human2query.query_to_sql(smartquery=smartquery, db_driver="MySQL")
+    response = human2query.query2sql(smartquery=smartquery, driver="MySQL")
     print(response)
-
-    # Query 2 OLAP
-    nl = "list all the revenue by player"
-    df = ""
-    schema = {
-        "SerieA.Revenue": {
-            "name":"revenue",
-            "synonyms": ["revenues"]
-        },
-        "SerieA.Player": {
-            "name": "player",
-            "synonyms": ["players", "soccer player"],
-            "example_of_values": ["Cristiano Ronaldo", "Ciro Immobile", "Alessandro del Piero"]
-        }
-    }
-    db_driver = "olap"
-
-    # Function call
-    result_for_ner = human2query.prepare_ner(nl=nl, schema=schema, db_driver=db_driver)
-    smartquery = human2query.query_to_smartquery(result_for_ner)
-    olap_query = human2query.smartquery_to_olap(smartquery)
-
-    # Print the DataFrame result
-    print("Answer: ")
-    print(result_for_ner)
-    print("#----#")
-    print(smartquery)
-    print("#----#")
-    print(olap_query)
-
-    # All
-    response = human2query.query_to_olap(nl=nl, schema=schema, db_driver=db_driver)
-    print("Answer: ")
+    response = human2query.complex_field_calculator(smartquery=smartquery, driver="MySQL")
+    print(response)
+    response = human2query.complex_filter_calculator(smartquery=smartquery, driver="MySQL")
     print(response)
